==> haskell-http-conduit-2.3.9.1-185-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-http-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 http-conduit
version:              2.3.9.1
visibility:           public
id:                   http-conduit-2.3.9.1-5P1WHi6SLyo9dv1b5uZb0k
key:                  http-conduit-2.3.9.1-5P1WHi6SLyo9dv1b5uZb0k
license:              BSD-3-Clause
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             https://github.com/snoyberg/http-client
synopsis:
    HTTP client package with conduit interface and HTTPS support.

description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/http-conduit>.

category:             Web, Conduit
abi:                  16050b02ab8ee5bee248c414df87359f
exposed:              True
exposed-modules:
    Network.HTTP.Client.Conduit Network.HTTP.Conduit
    Network.HTTP.Simple

import-dirs:          /usr/lib/ghc-9.6.6/site-local/http-conduit-2.3.9.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/http-conduit-2.3.9.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/http-conduit-2.3.9.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-http-conduit
hs-libraries:         HShttp-conduit-2.3.9.1-5P1WHi6SLyo9dv1b5uZb0k
depends:
    aeson-2.1.2.1-GojnAvr1Jep10WUNi5H1Pi
    attoparsec-0.14.4-8gkbEkDkw506qTMOo0v2nm
    attoparsec-aeson-2.1.0.0-4vY3J0brPwKGduZzr9qLSE base-4.18.2.1
    bytestring-0.11.5.3 conduit-1.3.6.1-252yfbtdylIFaQqQ0JKO9q
    conduit-extra-1.3.8-2AxhzRoObWI6EssRdl8CoW
    http-client-0.7.19-76DosIrYZ8GJOiYGyhGmc9
    http-client-tls-0.3.6.4-J61axw4VOrbKDwJUgwBVs6
    http-types-0.12.4-AM56akyPNdKBTyuGfrlHOS mtl-2.3.1
    resourcet-1.2.6-BDQ4bs2ZkKrFMSf2ISkWBx transformers-0.6.1.0
    unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY

haddock-interfaces:
    /usr/share/doc/haskell-http-conduit/html/http-conduit.haddock

haddock-html:         /usr/share/doc/haskell-http-conduit/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-http-conduit-2.3.9.1-188-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-http-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 http-conduit
version:              2.3.9.1
visibility:           public
id:                   http-conduit-2.3.9.1-4fv8UoY8zTlKlPGaK7tn4g
key:                  http-conduit-2.3.9.1-4fv8UoY8zTlKlPGaK7tn4g
license:              BSD-3-Clause
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             https://github.com/snoyberg/http-client
synopsis:
    HTTP client package with conduit interface and HTTPS support.

description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/http-conduit>.

category:             Web, Conduit
abi:                  885fe294b47079d616606be8045e6429
exposed:              True
exposed-modules:
    Network.HTTP.Client.Conduit Network.HTTP.Conduit
    Network.HTTP.Simple

import-dirs:          /usr/lib/ghc-9.6.6/site-local/http-conduit-2.3.9.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/http-conduit-2.3.9.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/http-conduit-2.3.9.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-http-conduit
hs-libraries:         HShttp-conduit-2.3.9.1-4fv8UoY8zTlKlPGaK7tn4g
depends:
    aeson-2.1.2.1-CpIoOLI7lIpJkSqSOmDN9y
    attoparsec-0.14.4-68EOoedQqwu8mpKj0RmtvE
    attoparsec-aeson-2.1.0.0-BEiLkT0rdCWAen0nBrmaBS base-4.18.2.1
    bytestring-0.11.5.3 conduit-1.3.6.1-5afbFXdQmpuHK8N5OCErlh
    conduit-extra-1.3.8-Dg42smPzbiF4Nemzj9bTg6
    http-client-0.7.19-9XP2fRtq348Edv4XKGE8tD
    http-client-tls-0.3.6.4-GXwyMNGv8mPI3u8Rlj5noc
    http-types-0.12.4-E9He9FXy4rKITKDtg1mhVt mtl-2.3.1
    resourcet-1.2.6-7GW6wEwAkCf499WYv26LMs transformers-0.6.1.0
    unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY

haddock-interfaces:
    /usr/share/doc/haskell-http-conduit/html/http-conduit.haddock

haddock-html:         /usr/share/doc/haskell-http-conduit/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
